@@ -784,6 +784,8 @@ class Class(hyperdb.Class):
         These operations trigger detectors and can be vetoed.  Attempts
         to modify the "creation" or "activity" properties cause a KeyError.
         """
+        if self.db.journaltag is None:
+            raise hyperdb.DatabaseError, _('Database open read-only')
         self.fireAuditors('create', None, propvalues)
         newid = self.create_inner(**propvalues)
         self.fireReactors('create', newid, None)
@@ -950,7 +952,7 @@ class Class(hyperdb.Class):
                 raise ValueError, 'Journalling is disabled for this class'
             journal = self.db.getjournal(self.classname, nodeid)
             if journal:
-                return self.db.getjournal(self.classname, nodeid)[0][1]
+                return journal[0][1]
             else:
                 # on the strange chance that there's no journal
                 return date.Date()
@@ -1045,6 +1047,9 @@ class Class(hyperdb.Class):
         These operations trigger detectors and can be vetoed.  Attempts
         to modify the "creation" or "activity" properties cause a KeyError.
         """
+        if self.db.journaltag is None:
+            raise hyperdb.DatabaseError, _('Database open read-only')
+
         self.fireAuditors('set', nodeid, propvalues)
         oldvalues = copy.deepcopy(self.db.getnode(self.classname, nodeid))
         for name,prop in self.getprops(protected=0).items():
@@ -2003,9 +2008,6 @@ class Class(hyperdb.Class):
                     if value is None:
                         pass
                     elif isinstance(prop, hyperdb.Date):
-                        if type(value) == type(()):
-                            print _('WARNING: invalid date tuple %r')%(value,)
-                            value = date.Date( "2000-1-1" )
                         value = date.Date(value)
                     elif isinstance(prop, hyperdb.Interval):
                         value = date.Interval(value)
