@@ -1,4 +1,4 @@
-#$Id$
+#$Id: back_postgresql.py,v 1.44 2008-08-07 05:50:03 richard Exp $
 #
 # Copyright (c) 2003 Martynas Sklyzmantas, Andrey Lebedev <andrey@micro.lt>
 #
@@ -9,7 +9,7 @@
 '''Postgresql backend via psycopg for Roundup.'''
 __docformat__ = 'restructuredtext'
 
-import os, shutil, popen2, time
+import os, shutil, time
 try:
     import psycopg
     from psycopg import QuotedString
