@@ -8,7 +8,7 @@ import unittest, os, shutil, errno, sys, difflib, cgi, re
 
 from roundup.cgi.exceptions import *
 from roundup import init, instance, password, hyperdb, date
-from roundup.xmlrpc import RoundupServer
+from roundup.xmlrpc import RoundupInstance
 from roundup.backends import list_backends
 
 import db_test_base
@@ -32,10 +32,11 @@ class TestCase(unittest.TestCase):
 
         self.db.commit()
         self.db.close()
-
-        self.server = RoundupServer(self.dirname)
+        self.db = self.instance.open('joe')
+        self.server = RoundupInstance(self.db, self.instance.actions, None)
 
     def tearDown(self):
+        self.db.close()
         try:
             shutil.rmtree(self.dirname)
         except OSError, error:
@@ -43,63 +44,76 @@ class TestCase(unittest.TestCase):
 
     def testAccess(self):
         # Retrieve all three users.
-        results = self.server.list('joe', 'random', 'user', 'id')
+        results = self.server.list('user', 'id')
         self.assertEqual(len(results), 3)
 
         # Obtain data for 'joe'.
-        results = self.server.display('joe', 'random', self.joeid)
+        results = self.server.display(self.joeid)
         self.assertEqual(results['username'], 'joe')
         self.assertEqual(results['realname'], 'Joe Random')
 
     def testChange(self):
         # Reset joe's 'realname'.
-        results = self.server.set('joe', 'random', self.joeid,
-            'realname=Joe Doe')
-        results = self.server.display('joe', 'random', self.joeid,
-            'realname')
+        results = self.server.set(self.joeid, 'realname=Joe Doe')
+        results = self.server.display(self.joeid, 'realname')
         self.assertEqual(results['realname'], 'Joe Doe')
 
         # check we can't change admin's details
-        self.assertRaises(Unauthorised, self.server.set, 'joe', 'random',
-            'user1', 'realname=Joe Doe')
+        self.assertRaises(Unauthorised, self.server.set, 'user1', 'realname=Joe Doe')
 
     def testCreate(self):
-        results = self.server.create('joe', 'random', 'issue', 'title=foo')
+        results = self.server.create('issue', 'title=foo')
         issueid = 'issue' + results
-        results = self.server.display('joe', 'random', issueid, 'title')
+        results = self.server.display(issueid, 'title')
         self.assertEqual(results['title'], 'foo')
 
     def testFileCreate(self):
-        results = self.server.create('joe', 'random', 'file', 'content=hello\r\nthere')
+        results = self.server.create('file', 'content=hello\r\nthere')
         fileid = 'file' + results
-        results = self.server.display('joe', 'random', fileid, 'content')
+        results = self.server.display(fileid, 'content')
         self.assertEqual(results['content'], 'hello\r\nthere')
 
-    def testAuthUnknown(self):
-        # Unknown user (caught in XMLRPC frontend).
-        self.assertRaises(Unauthorised, self.server.list,
-            'nobody', 'nobody', 'user', 'id')
+    def testAction(self):
+        # As this action requires special previledges, we temporarily switch
+        # to 'admin'
+        self.db.setCurrentUser('admin')
+        users_before = self.server.list('user')
+        try:
+            tmp = 'user' + self.db.user.create(username='tmp')
+            self.server.action('retire', tmp)
+        finally:
+            self.db.setCurrentUser('joe')
+        users_after = self.server.list('user')
+        self.assertEqual(users_before, users_after)
 
     def testAuthDeniedEdit(self):
         # Wrong permissions (caught by roundup security module).
         self.assertRaises(Unauthorised, self.server.set,
-            'joe', 'random', 'user1', 'realname=someone')
+                          'user1', 'realname=someone')
 
     def testAuthDeniedCreate(self):
         self.assertRaises(Unauthorised, self.server.create,
-            'joe', 'random', 'user', {'username': 'blah'})
+                          'user', {'username': 'blah'})
 
     def testAuthAllowedEdit(self):
+        self.db.setCurrentUser('admin')
         try:
-            self.server.set('admin', 'sekrit', 'user2', 'realname=someone')
-        except Unauthorised, err:
-            self.fail('raised %s'%err)
+            try:
+                self.server.set('user2', 'realname=someone')
+            except Unauthorised, err:
+                self.fail('raised %s'%err)
+        finally:
+            self.db.setCurrentUser('joe')
 
     def testAuthAllowedCreate(self):
+        self.db.setCurrentUser('admin')
         try:
-            self.server.create('admin', 'sekrit', 'user', 'username=blah')
-        except Unauthorised, err:
-            self.fail('raised %s'%err)
+            try:
+                self.server.create('user', 'username=blah')
+            except Unauthorised, err:
+                self.fail('raised %s'%err)
+        finally:
+            self.db.setCurrentUser('joe')
 
 def test_suite():
     suite = unittest.TestSuite()
